@@ -1,6 +1,6 @@
 package Method::ParamValidator;
 
-$Method::ParamValidator::VERSION   = '0.13';
+$Method::ParamValidator::VERSION   = '0.14';
 $Method::ParamValidator::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Method::ParamValidator - Configurable method parameter validator.
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
@@ -57,9 +57,6 @@ as of now but will be extended as per the requirements.
     $validator->add_method({ name   => 'add_user',
                              fields => { firstname => 1, lastname => 1, age => 1, sex => 0 }});
 
-    use Test::More;
-    use Test::Exception;
-
     throws_ok { $validator->validate('get_xyz')  }     qr/Invalid method name received/;
     throws_ok { $validator->validate('add_user') }     qr/Missing parameters/;
     throws_ok { $validator->validate('add_user', []) } qr/Invalid parameters data structure/;
@@ -76,7 +73,7 @@ as of now but will be extended as per the requirements.
 
 =head2 Setting up method validator using configuration file.
 
-Sample configuration file in JSON format.
+Sample configuration file in C<JSON> format.
 
     { "fields"  : [ { "name" : "firstname", "format" : "s" },
                     { "name" : "lastname",  "format" : "s" },
@@ -93,7 +90,7 @@ Sample configuration file in JSON format.
                   ]
     }
 
-Then you just need one line to get everything setup using the above configuration file (config.json).
+Then you just need one line to get everything setup using the above configuration file C<config.json>.
 
     use strict; use warnings;
     use Test::More;
@@ -162,9 +159,9 @@ Using the above configuration file test the code as below:
 
 =head2 Plug-n-Play with Moo package
 
-Lets start with a basic Moo package PlayMath.
+Lets start with a basic Moo package C<Calculator>.
 
-    package PlayMath;
+    package Calculator;
 
     use Moo;
     use namespace::autoclean;
@@ -185,7 +182,7 @@ Lets start with a basic Moo package PlayMath.
 
     1;
 
-Now we need to create configuration file for the package PlayMath as below:
+Now we need to create configuration file for the package C<Calculator> as below:
 
     { "fields"  : [ { "name" : "op", "format" : "s", "source": [ "add", "sub", "mul" ] },
                     { "name" : "a",  "format" : "d" },
@@ -200,7 +197,7 @@ Now we need to create configuration file for the package PlayMath as below:
                   ]
     }
 
-Finally plug the validator to the package PlayMath as below:
+Finally plug the validator to the package C<Calculator> as below:
 
     use Method::ParamValidator;
 
@@ -217,26 +214,24 @@ Finally plug the validator to the package PlayMath as below:
         $self->validator->validate($2, $param);
     };
 
-Here is unit test for the package PlayMath.
+Here is unit test for the package C<Calculator>.
 
     use strict; use warnings;
     use Test::More;
     use Test::Exception;
-    use PlayMath;
+    use Calculator;
 
-    my $math = PlayMath->new;
+    my $calc = Calculator->new;
 
-    is($math->do({ op => 'add', a => 4, b => 2 }), 6);
+    is($calc->do({ op => 'add', a => 4, b => 2 }), 6);
+    is($calc->do({ op => 'sub', a => 4, b => 2 }), 2);
+    is($calc->do({ op => 'mul', a => 4, b => 2 }), 8);
 
-    is($math->do({ op => 'sub', a => 4, b => 2 }), 2);
-
-    is($math->do({ op => 'mul', a => 4, b => 2 }), 8);
-
-    throws_ok { $math->do({ op => 'add' }) } qr/Missing required parameter. \(a\)/;
-    throws_ok { $math->do({ op => 'add', a => 1 }) } qr/Missing required parameter. \(b\)/;
-    throws_ok { $math->do({ op => 'x', a => 1, b => 2 }) } qr/Parameter failed check constraint. \(op\)/;
-    throws_ok { $math->do({ op => 'add', a => 'x', b => 2 }) } qr/Parameter failed check constraint. \(a\)/;
-    throws_ok { $math->do({ op => 'add', a => 1, b => 'x' }) } qr/Parameter failed check constraint. \(b\)/;
+    throws_ok { $calc->do({ op => 'add' }) } qr/Missing required parameter. \(a\)/;
+    throws_ok { $calc->do({ op => 'add', a => 1 }) } qr/Missing required parameter. \(b\)/;
+    throws_ok { $calc->do({ op => 'x', a => 1, b => 2 }) } qr/Parameter failed check constraint. \(op\)/;
+    throws_ok { $calc->do({ op => 'add', a => 'x', b => 2 }) } qr/Parameter failed check constraint. \(a\)/;
+    throws_ok { $calc->do({ op => 'add', a => 1, b => 'x' }) } qr/Parameter failed check constraint. \(b\)/;
 
     done_testing();
 
@@ -398,7 +393,7 @@ Add field to the validator. Parameters are defined as below:
     |         |                                                                 |
     | check   | Optional code ref to validate field value.                      |
     |         |                                                                 |
-    | source  | Optional hashref to validate field value againsts.              |
+    | source  | Optional hashref to validate field value against.               |
     |         |                                                                 |
     | message | Optional field message.                                         |
     |         |                                                                 |
